From cb0ddc563482ccbad9331d944c711cd180f38400 Mon Sep 17 00:00:00 2001
From: Laurent Montel <montel@kde.org>
Date: Thu, 24 Feb 2022 17:30:26 +0100
Subject: [PATCH] Make it compile without texttospeach

---
 .../webengine/articleviewerwebengine.cpp             |  5 +++++
 .../webengine/articleviewerwebenginewidgetng.cpp     | 12 ++++++++----
 .../webengine/articleviewerwebenginewidgetng.h       |  4 ++++
 src/frame/webengine/akrwebengineviewer.cpp           |  5 +++++
 4 files changed, 22 insertions(+), 4 deletions(-)

diff --git a/src/articleviewer-ng/webengine/articleviewerwebengine.cpp b/src/articleviewer-ng/webengine/articleviewerwebengine.cpp
index 787efefc..e308df8a 100644
--- a/src/articleviewer-ng/webengine/articleviewerwebengine.cpp
+++ b/src/articleviewer-ng/webengine/articleviewerwebengine.cpp
@@ -12,7 +12,10 @@
 #include "articleviewerwebenginepage.h"
 #include "urlhandler/webengine/urlhandlerwebengine.h"
 #include "webengine/urlhandlerwebenginemanager.h"
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeech>
+#endif
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
 #include <WebEngineViewer/WebEngineManageScript>
@@ -305,10 +308,12 @@ void ArticleViewerWebEngine::slotWebHitFinished(const WebEngineViewer::WebHitTes
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("tab_unmute")));
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("find_in_messages")));
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
         popup.addSeparator();
         popup.addAction(ActionManager::getInstance()->action(QStringLiteral("speak_text")));
     }
+#endif
     popup.exec(mapToGlobal(result.pos()));
 }
 
diff --git a/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.cpp b/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.cpp
index e806b343..3784894e 100644
--- a/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.cpp
+++ b/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.cpp
@@ -12,9 +12,9 @@
 #include <KLocalizedString>
 #include <QVBoxLayout>
 #include <viewerplugintoolmanager.h>
-
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/kpimtextedit/texttospeechwidget.h>
-
+#endif
 #include <KPIMTextEdit/SlideContainer>
 
 #include <WebEngineViewer/FindBarWebEngineView>
@@ -45,7 +45,9 @@ template<typename Arg, typename R, typename C> InvokeWrapper<Arg, R, C> invoke(R
 ArticleViewerWebEngineWidgetNg::ArticleViewerWebEngineWidgetNg(ArticleViewerWebEngine *customViewer, KActionCollection *ac, QWidget *parent)
     : QWidget(parent)
     , mArticleViewerNg(customViewer)
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     , mTextToSpeechWidget(new KPIMTextEdit::TextToSpeechWidget(this))
+#endif
     , mSliderContainer(new KPIMTextEdit::SlideContainer(this))
     , mTrackingWarningWidget(new WebEngineViewer::TrackingWarningWidget(this))
 
@@ -62,10 +64,10 @@ void ArticleViewerWebEngineWidgetNg::initializeLayout(KActionCollection *ac)
 {
     auto layout = new QVBoxLayout(this);
     layout->setContentsMargins({});
-
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     mTextToSpeechWidget->setObjectName(QStringLiteral("texttospeechwidget"));
     layout->addWidget(mTextToSpeechWidget);
-
+#endif
     mTrackingWarningWidget->setObjectName(QStringLiteral("mTrackingWarningWidget"));
     layout->addWidget(mTrackingWarningWidget);
 
@@ -107,7 +109,9 @@ void ArticleViewerWebEngineWidgetNg::slotFind()
 void ArticleViewerWebEngineWidgetNg::slotSpeakText()
 {
     const QString text = mArticleViewerNg->selectedText();
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     mTextToSpeechWidget->say(text);
+#endif
 }
 
 void ArticleViewerWebEngineWidgetNg::saveCurrentPosition()
diff --git a/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.h b/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.h
index a9ff9eea..f4834d2e 100644
--- a/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.h
+++ b/src/articleviewer-ng/webengine/articleviewerwebenginewidgetng.h
@@ -8,6 +8,8 @@
 
 #include "akregator_export.h"
 #include "articleviewerwebengine.h"
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+
 #include <QWidget>
 class QPrinter;
 class KActionCollection;
@@ -55,7 +57,9 @@ private:
     void printRequested(QWebEnginePage *page);
     WebEngineViewer::FindBarWebEngineView *mFindBarWebView = nullptr;
     ArticleViewerWebEngine *mArticleViewerNg = nullptr;
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     KPIMTextEdit::TextToSpeechWidget *const mTextToSpeechWidget;
+#endif
     KPIMTextEdit::SlideContainer *const mSliderContainer;
     WebEngineViewer::TrackingWarningWidget *const mTrackingWarningWidget;
     QPrinter *mCurrentPrinter = nullptr;
diff --git a/src/frame/webengine/akrwebengineviewer.cpp b/src/frame/webengine/akrwebengineviewer.cpp
index 53b5e5f8..d49e0a8c 100644
--- a/src/frame/webengine/akrwebengineviewer.cpp
+++ b/src/frame/webengine/akrwebengineviewer.cpp
@@ -15,7 +15,10 @@
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KIO/KUriFilterSearchProviderActions>
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeech>
+#endif
 #include <QContextMenuEvent>
 #include <QMenu>
 #include <QWebEngineHistory>
@@ -138,11 +141,13 @@ void AkrWebEngineViewer::slotWebHitFinished(const WebEngineViewer::WebHitTestRes
         popup.addActions(interceptorUrlActions);
     }
     popup.addSeparator();
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("find_in_messages")));
     if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
         popup.addSeparator();
         popup.addAction(ActionManager::getInstance()->action(QStringLiteral("speak_text")));
     }
+#endif
     popup.exec(mapToGlobal(result.pos()));
 }
 
-- 
GitLab

